@@ -594,18 +594,15 @@ static int KIP_PrepareConversion
 
   /* Хåꡣrealize ƤǤǤʤΤǡ *
    * 뤳Ȥˤʤ롣*/
-  XtAddCallback
-    ( client->skkinput, XtNfixNotify,
-      ( XtCallbackProc )KIP_SendMessageToRequestorCallback,
-      ( XtPointer )client ) ;
-  XtAddCallback
-    ( client->skkinput, XtNendNotify,
-      ( XtCallbackProc )KIP_EndMessageToRequestorCallback,
-      ( XtPointer )client ) ;
-  XtAddCallback
-    ( client->skkinput, XtNkeybackNotify,
-      ( XtCallbackProc )KIP_KeyEventToRequestorCallback,
-      ( XtPointer )client ) ;
+  XtAddCallback (client->skkinput, XtNfixNotify,
+				 ( XtCallbackProc )KIP_SendMessageToRequestorCallback,
+				 ( XtPointer )client ) ;
+  XtAddCallback ( client->skkinput, XtNendNotify,
+				  ( XtCallbackProc )KIP_EndMessageToRequestorCallback,
+				  ( XtPointer )client ) ;
+  XtAddCallback ( client->skkinput, XtNkeybackNotify,
+				  ( XtCallbackProc )KIP_KeyEventToRequestorCallback,
+				  ( XtPointer )client ) ;
   /* Widget  realize Ƥޤ°λƤ*/
   if( client->protocol == PROTOCOL_TYPE_KINPUT2 ){
 #if 0
@@ -1132,9 +1129,9 @@ static struct ConvAttrsMesg KIP_ReadAttribute
 	case CONVERSION_ATTRIBUTE_COLOR :
 		if( attribute_length != 2 )
 			break ;
-		camsg.mask |= CAColor ;
-		camsg.value.foreground = attributes[ 0 ] ;
-		camsg.value.background = attributes[ 1 ] ;
+		camsg.mask |= (CAForegroundPixel | CABackgroundPixel) ;
+		camsg.value.foreground = attributes [0] ;
+		camsg.value.background = attributes [1] ;
 		break ;
 		/* Ѵ饤ȤΥեȤξ*/
 	case CONVERSION_ATTRIBUTE_FONT_ATOMS :
