@@ -24,14 +24,10 @@
 #define NO_EVENT_HANDLE		(-1)
 
 /*
- * $B4X?t$N%W%m%H%?%$%W@k8@!#(B
+ * ؿΥץȥ
  */
-int add_myeventhandler
-( Display *disp, Window src_win, Window dest_win,
-  int event_type, long event_mask ) ;
-int remove_allmyeventhandler
-( Display *disp, Window src_win ) ;
-int remove_myeventhandler
-( Display *disp, Window src_win, int event_type, 
-  unsigned long event_mask ) ;
+int		add_myeventhandler			(Display*, Window, Window, int, long) ;
+int		remove_allmyeventhandler	(Display*, Window) ;
+int		remove_myeventhandler		(Display*, Window, int, unsigned long) ;
 #endif
+
