@@ -262,7 +262,7 @@ static void OFFW_InitializeHistory( Widget gw )
 		return ;
 	}
 	/* ꤷȤСġ*/
-	if( w->offthespotWin.historyAttribute->overthespot_like_input < 0 ){
+	if( w->offthespotWin.historyAttribute->overthespot_like_input == False){
 		/* X Resource ¦ꤹ롣*/
 		w->offthespotWin.buffer.overthespot_like_input = 
 			w->offthespotWin.overthespotLikeInput ;
@@ -994,36 +994,6 @@ static int OFFW_ReconfigureFocusPosition
   return ret ;
 }
 
-/*
- * ʤ굯ưƤʳǥեưȤ̵
- * ꤤ(̿δְ㤤ʤΤ)򲿤Ȥؿ 
- *----
- * Netscape ׵ФƤΤǡޤ
- * οͤˤȤäƤϡNetscape ơNetscape ܸ첽ޤơBus 
- * Error С kinput2  skkinput ΤʤΡ
- * ƤȤ顣錄ᤷǤʾС
- */
-static void OFFW_ChangeFocusWindow
-( Widget gw, Window focus_win )
-{
-  OffthespotWinWidget w = ( OffthespotWinWidget )gw ;
-
-  /* focus window ˤϤĤƤɥ˴롣*/
-  XDestroyWindow( XtDisplay( gw ), w->offthespotWin.canvas_win ) ;
-  w->offthespotWin.canvas_win = OFFW_CreateSubCanvas
-    ( gw, focus_win, &w->offthespotWin.canvas_probe, 0 ) ;
-
-  XDestroyWindow( XtDisplay( gw ), w->offthespotWin.modeshell_win ) ;
-  w->offthespotWin.modeshell_win = OFFW_CreateSubCanvas
-    ( gw, focus_win, &w->offthespotWin.modeshell_probe, 
-      w->offthespotWin.modeshell_border_width ) ;
-
-  w->offthespotWin.focus_window = focus_win ;
-  OFFW_ReleaseAllGCs( gw ) ;
-  OFFW_CreateAllGCs( gw ) ;
-  return ;
-}
-
 /*
  * Ѵ饤ȤΡѴ°ν׵פ򤵤Фؿ
  */
@@ -1043,7 +1013,7 @@ static int OFFW_ChangeAttributes
 			/* ꤷȦΥեʪˤʤäƤ顢̣Ǥ */
 			/* ʤ ȤäǤ*/
 			if( w->offthespotWin.focus_window != None ){
-				OFFW_ChangeFocusWindow( gw, values->focus_window ) ;
+				w->offthespotWin.focus_window = values->focus_window ;
 				w->offthespotWin.attribute_mask &= ~( CAStatusArea ) ;
 			} else {
 				w->offthespotWin.focus_window = values->focus_window ;
