@@ -261,7 +261,7 @@ OnWin_InitializeHistory (
 		return ;
 	}
 	/* ꤷȤСġ*/
-	if (w->onthespotWin.historyAttribute->overthespot_like_input < 0){
+	if (w->onthespotWin.historyAttribute->overthespot_like_input == False){
 		/* X Resource ¦ꤹ롣*/
 		w->onthespotWin.buffer.overthespot_like_input = 
 			w->onthespotWin.overthespotLikeInput ;
