@@ -282,7 +282,7 @@ static void OTSW_InitializeHistory (Widget gw)
     return ;
   }
   /* ꤷȤСġ*/
-  if (w->overthespotWin.historyAttribute->overthespot_like_input < 0){
+  if (w->overthespotWin.historyAttribute->overthespot_like_input == False){
     /* X Resource ¦ꤹ롣*/
     w->overthespotWin.buffer.overthespot_like_input = 
       w->overthespotWin.overthespotLikeInput ;
@@ -513,78 +513,78 @@ static Window OTSW_CreateModeShellWin
 static Window OTSW_CreateSubCanvas
  (Widget gw, Window focus_window, int *probe, int border_width)
 {
-  OverthespotWinWidget	w	=  (OverthespotWinWidget)gw ;
-  Window		win ;
-  XSetWindowAttributes	xswa ;
-
-  if (border_width <= 0){
-    win = XCreateSimpleWindow
-       (XtDisplay (gw), focus_window, 0, 0, 1, 1, 0,
-	w->overthespotWin.obackground,
-	w->overthespotWin.obackground) ;
-  } else {
-    win = XCreateSimpleWindow
-       (XtDisplay (gw), focus_window, 0, 0, 1, 1, border_width,
-	w->overthespotWin.oforeground,
-	w->overthespotWin.obackground) ;
-  }
-  add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), Expose, ExposureMask) ;
-  add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), KeyPress, KeyPressMask) ;
-  add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), KeyRelease, KeyReleaseMask) ;
-  add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), DestroyNotify, SubstructureNotifyMask) ;
-
-  /* SaveUnder ˤʤ modeshell ΰưˤä ExposureEvent ƤǤޤ*/
-  xswa.save_under = True ;
-  XChangeWindowAttributes (XtDisplay(gw), win, CWSaveUnder, &xswa) ;
-
-  /* avoid Unmap on Qt by setting over-ride-redirect */
-  xswa.override_redirect = True ;
-  XChangeWindowAttributes (XtDisplay(gw), win, CWOverrideRedirect, &xswa) ;
-
-  /* ϤΤɬפˤʤޤǤϡmap ʤ*/
-  *probe = False ;
-  return win ;
+	OverthespotWinWidget	w	=  (OverthespotWinWidget)gw ;
+	Window		win ;
+	XSetWindowAttributes	xswa ;
+	
+	if (border_width <= 0){
+		win = XCreateSimpleWindow
+			(XtDisplay (gw), focus_window, 0, 0, 1, 1, 0,
+			 w->overthespotWin.obackground,
+			 w->overthespotWin.obackground) ;
+	} else {
+		win = XCreateSimpleWindow
+			(XtDisplay (gw), focus_window, 0, 0, 1, 1, border_width,
+			 w->overthespotWin.oforeground,
+			 w->overthespotWin.obackground) ;
+	}
+	add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), Expose, ExposureMask) ;
+	add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), KeyPress, KeyPressMask) ;
+	add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), KeyRelease, KeyReleaseMask) ;
+	add_myeventhandler  (XtDisplay (gw), win, XtWindow (gw), DestroyNotify, SubstructureNotifyMask) ;
+	
+	/* SaveUnder ˤʤ modeshell ΰưˤä ExposureEvent ƤǤޤ*/
+	xswa.save_under = True ;
+	XChangeWindowAttributes (XtDisplay(gw), win, CWSaveUnder, &xswa) ;
+	
+	/* avoid Unmap on Qt by setting over-ride-redirect */
+	xswa.override_redirect = True ;
+	XChangeWindowAttributes (XtDisplay(gw), win, CWOverrideRedirect, &xswa) ;
+	
+	/* ϤΤɬפˤʤޤǤϡmap ʤ*/
+	*probe = False ;
+	return win ;
 }
 
 static int OTSW_ParseModeShellGeometry(Widget gw)
 {
-  OverthespotWinWidget ow = (OverthespotWinWidget)gw;
-  int x, y;
-  unsigned int w, h;
-  int r;
+	OverthespotWinWidget ow = (OverthespotWinWidget)gw;
+	int x, y;
+	unsigned int w, h;
+	int r;
 
-  x = y = 0;
-  w = h = 0;
-  r = XParseGeometry(ow->overthespotWin.modeshell_geometry, &x, &y, &w, &h);
-  if (r == 0) {
-    /* not specified, or invalid geometry */
-    return 0;
-  }
-  if ((r & XValue) == XValue) {
-    ow->overthespotWin.modeshell_x = x;
-  }
-  if ((r & YValue) == YValue) {
-    ow->overthespotWin.modeshell_y = y;
-  }
-  /* not recommended? */
-  if ((r & WidthValue) == WidthValue) {
-    ow->overthespotWin.modeshell_width = w;
-  }
-  if ((r & HeightValue) == HeightValue) {
-    ow->overthespotWin.modeshell_height = h;
-  }
-
-  if ((r & XNegative) == XNegative) {
-    ow->overthespotWin.modeshell_x = 
-      DisplayWidth (XtDisplay (gw), DefaultScreen (XtDisplay (gw))) 
-      - ow->overthespotWin.modeshell_width - 10;
-  }
-  if ((r & YNegative) == YNegative) {
-    ow->overthespotWin.modeshell_y = 
-      DisplayHeight (XtDisplay (gw), DefaultScreen (XtDisplay (gw))) 
-      - ow->overthespotWin.modeshell_height - 10;
-  }
-  return r;
+	x = y = 0;
+	w = h = 0;
+	r = XParseGeometry(ow->overthespotWin.modeshell_geometry, &x, &y, &w, &h);
+	if (r == 0) {
+		/* not specified, or invalid geometry */
+		return 0;
+	}
+	if ((r & XValue) == XValue) {
+		ow->overthespotWin.modeshell_x = x;
+	}
+	if ((r & YValue) == YValue) {
+		ow->overthespotWin.modeshell_y = y;
+	}
+	/* not recommended? */
+	if ((r & WidthValue) == WidthValue) {
+		ow->overthespotWin.modeshell_width = w;
+	}
+	if ((r & HeightValue) == HeightValue) {
+		ow->overthespotWin.modeshell_height = h;
+	}
+	
+	if ((r & XNegative) == XNegative) {
+		ow->overthespotWin.modeshell_x = 
+			DisplayWidth (XtDisplay (gw), DefaultScreen (XtDisplay (gw))) 
+			- ow->overthespotWin.modeshell_width - 10;
+	}
+	if ((r & YNegative) == YNegative) {
+		ow->overthespotWin.modeshell_y = 
+			DisplayHeight (XtDisplay (gw), DefaultScreen (XtDisplay (gw))) 
+			- ow->overthespotWin.modeshell_height - 10;
+	}
+	return r;
 }
 
 /*
@@ -602,14 +602,13 @@ static void OTSW_CreateModeShell (Widget gw)
 	Window parentwin ;
 	int border_width ;
 
+	parentwin    = w->overthespotWin.client_window ;
 	if ((w->overthespotWin.attribute_mask & CAStatusArea) &&
 		w->overthespotWin.client_window != w->overthespotWin.focus_window){
 		/* ξˤϡ⡼ɥˤ롣*/
-		parentwin    = w->overthespotWin.client_window ;
 		border_width = 0 ;
 		w->overthespotWin.fixed_modeshell = True ;
 	} else {
-		parentwin    = w->overthespotWin.focus_window ;
 		border_width = w->overthespotWin.modeshell_border_width ;
 		w->overthespotWin.fixed_modeshell = False ;
 	}
@@ -759,6 +758,7 @@ static void OTSW_Realize (
 {
 	register OverthespotWinWidget	w		= (OverthespotWinWidget)gw ;
 	register CoreWidgetClass		super	= (CoreWidgetClass)XtClass (gw)->core_class.superclass ;
+	register Window					wndParent ;
 
 	/* ŬڤʥɥѰդƤ*/
 	(*super->core_class.realize) (gw, valueMask, attrs) ;
@@ -778,8 +778,8 @@ static void OTSW_Realize (
 			XGetRectangleOfWindow
 				(XtDisplay (gw), w->overthespotWin.focus_window, 
 				 &w->overthespotWin.client_area) ;
-		OTSW_ReconfigureFocusPosition (gw) ;
 	}
+	OTSW_ReconfigureFocusPosition (gw) ;
 	OTSW_CreateAllGCs (gw) ;
 	
 	/* Minibuffer 롣*/
@@ -795,15 +795,13 @@ static void OTSW_Realize (
 	OTSW_CreateModeShell (gw) ;
 
 	/* ʸѤΥХ3ɬפˤʤ롣*/
+	wndParent	= w->overthespotWin.client_window ;
 	w->overthespotWin.topline_win = OTSW_CreateSubCanvas
-		(gw, w->overthespotWin.focus_window, 
-		 &w->overthespotWin.topline_probe, 0) ;
+		(gw, wndParent, &w->overthespotWin.topline_probe, 0) ;
 	w->overthespotWin.midline_win = OTSW_CreateSubCanvas
-		(gw, w->overthespotWin.focus_window, 
-		 &w->overthespotWin.midline_probe, 0) ;
+		(gw, wndParent, &w->overthespotWin.midline_probe, 0) ;
 	w->overthespotWin.botline_win = OTSW_CreateSubCanvas
-		(gw, w->overthespotWin.focus_window, 
-		 &w->overthespotWin.botline_probe, 0) ;
+		(gw, wndParent, &w->overthespotWin.botline_probe, 0) ;
 	
 	/*
 	 * ΰ֤ʤ⡼ɥƤʤ
@@ -1261,14 +1259,12 @@ static int OTSW_ChangeAttributes
 			} else {
 				w->overthespotWin.focus_window = values->focus_window ;
 			}
-			/* Ѵ饤ȤΰФ̵ä鼫Ѱդ *
-			 * 줬ɤʤݾڤϤʤΤɡѴ *
-			 * Ȥʤ̵ */
 			if (!((w->overthespotWin.attribute_mask) & CAClientArea)){
 				XGetRectangleOfWindow
 					(XtDisplay (gw), w->overthespotWin.focus_window,
 					 &w->overthespotWin.client_area) ;
 			}
+			OTSW_ReconfigureFocusPosition (gw) ;
 			ret = True ;
 		}
 	}
@@ -1581,11 +1577,11 @@ static int OTSW_FullDrawTopBufferMiddleLines
 
 static void XQueryPopdown (Widget gw, int *probe, Window win)
 {
-  if (probe){
-    XUnmapWindow (XtDisplay (gw), win) ;
-    *probe = False ;
-  }
-  return ;
+	if (probe){
+		XUnmapWindow (XtDisplay (gw), win) ;
+		*probe = False ;
+	}
+	return ;
 }
 
 /*
@@ -1594,227 +1590,221 @@ static void XQueryPopdown (Widget gw, int *probe, Window win)
  */
 static void OTSW_CalcSizeOfBufferWindows (Widget gw)
 {
-  OverthespotWinWidget w =  (OverthespotWinWidget)gw ;
-  int x, y; 			/* ɽ */
-  int width, height ;		/* ̥*/
-  struct SKKInputNode *node ;
-  struct myChar *text ;
-  struct myChar *line_top, *midline_top ;
-  int cursor_flag, pos, linetop_pos, line_num, midline_pos = 0 ;
-  int xdiff ;			/* ʸ*/
-
-  /* ޤɸ򥻥åȤƤ*/
-  x = w->overthespotWin.spot_x ;
-  y = w->overthespotWin.spot_y ;
-
-  /* ɽΰ礭ȤΤ׻Ƥ*/
-  width  = w->overthespotWin.client_area.width + 
-    w->overthespotWin.client_area.x ;
-  height = w->overthespotWin.client_area.height +
-    w->overthespotWin.client_area.y ;
-
-  /* Ĵ٤ʤФʤʤʸƬˤ碌Ƥ*/
-  node = w->overthespotWin.buffer.topbuffer ;
-  text = node->textbuffer ;
-
-  if (IS_END_OF_STRING (*text)){
-    /* ʸ󤬰ĤäƤʤä顢ХåեȤɽ뤿 *
-     * ʤƤΤפˤʤΤ顢äƤޤλˡ *
-     * ¸ߤƤʤ褦äƤޤܤƤޤΤ *
-     * դ뤳 */
-    XQueryPopdown
-       (gw, &w->overthespotWin.topline_probe, 
-	w->overthespotWin.topline_win) ;
-    XQueryPopdown
-       (gw, &w->overthespotWin.midline_probe, 
-	w->overthespotWin.midline_win) ;
-    XQueryPopdown
-       (gw, &w->overthespotWin.botline_probe, 
-	w->overthespotWin.botline_win) ;
-    w->overthespotWin.canvas_lines = 0 ;
-    return ;
-  }
-  line_top    = text ;
-  linetop_pos = 0 ;
-  line_num    = 0 ;
-  midline_top = NULL ;
-  cursor_flag = False ;
-
-  /* Ĵ٤뤳Ȥˤʤ롣*/
-  for (pos = 0 ; !IS_END_OF_STRING (*text) ; text ++, pos ++){
-    xdiff = myCharTextWidth (w->overthespotWin.fontset, text, 1) ;
-    if ((x + xdiff) >= width){
-      if ((y + w->overthespotWin.font_height) >= height){
-	goto exit_loop ;
-      } else {
-	y += w->overthespotWin.font_height ;
-	x =  w->overthespotWin.client_area.x ;
-	line_num ++ ;
-      }
-      /* Ƭΰ֤ФƤϥɽȤΤɬס*/
-      line_top    = text ;
-      linetop_pos = pos ;
-      /* 2ܤιƬ֤ФƤ*/
-      if (midline_top == NULL){
-	midline_top = line_top ;
-	midline_pos = linetop_pos ;
-      }
-    }
-    /* ɽʤΤɤȽꤹ롣*/
-    if (pos == node->cur_pos &&
-	 (( (y + w->overthespotWin.font_height) < height)))
-      cursor_flag = True ;
-    if (IS_ASCII_EQUAL (*text, '\n')){
-      if ((y + w->overthespotWin.font_height) >= height){
-	goto exit_loop ;
-      } else {
-	y += w->overthespotWin.font_height ;
-	x =  w->overthespotWin.client_area.x ;
-	line_num ++ ;
-      }
-      /* Ƭΰ֤ФƤϥɽȤΤɬס
-       */
-      line_top    = text + 1 ;
-      linetop_pos = pos + 1 ;
-      /* 2ܤιƬ֤ФƤ*/
-      if (midline_top == NULL){
-	midline_top = line_top ;
-	midline_pos = linetop_pos ;
-      }
-    } else {
-      x += xdiff ;
-    }
-  }
-  /* ޤǤǥ뤬ɽƤʤäν*/
-  if (!cursor_flag){
-    /* Ԥɬפꡩ */
-    if ((x + w->overthespotWin.cursor_width) >= width){
-      if ((y + w->overthespotWin.font_height) < height){
-	y += w->overthespotWin.font_height ;
-	line_num ++ ;
-	x = w->overthespotWin.client_area.x ;
+	OverthespotWinWidget w =  (OverthespotWinWidget)gw ;
+	int x, y; 			/* ɽ */
+	int width, height ;		/* ̥*/
+	struct SKKInputNode *node ;
+	struct myChar *text ;
+	struct myChar *line_top, *midline_top ;
+	int cursor_flag, pos, linetop_pos, line_num, midline_pos = 0 ;
+	int xdiff ;			/* ʸ*/
+	register int	focus_offset_x, focus_offset_y ;
+	
+	/* ޤɸ򥻥åȤƤ*/
+	x 					= w->overthespotWin.spot_x ;
+	y 					= w->overthespotWin.spot_y ;
+	focus_offset_x		= w->overthespotWin.focus_offset_x ;
+	focus_offset_y		= w->overthespotWin.focus_offset_y ;
+	
+	/* ɽΰ礭ȤΤ׻Ƥ*/
+	width  = w->overthespotWin.client_area.width + 
+		w->overthespotWin.client_area.x ;
+	height = w->overthespotWin.client_area.height +
+		w->overthespotWin.client_area.y ;
+	
+	/* Ĵ٤ʤФʤʤʸƬˤ碌Ƥ*/
+	node = w->overthespotWin.buffer.topbuffer ;
+	text = node->textbuffer ;
+	
+	if (IS_END_OF_STRING (*text)){
+		/* ʸ󤬰ĤäƤʤä顢ХåեȤɽ뤿 *
+		 * ʤƤΤפˤʤΤ顢äƤޤλˡ *
+		 * ¸ߤƤʤ褦äƤޤܤƤޤΤ *
+		 * դ뤳 */
+		XQueryPopdown
+			(gw, &w->overthespotWin.topline_probe, 
+			 w->overthespotWin.topline_win) ;
+		XQueryPopdown
+			(gw, &w->overthespotWin.midline_probe, 
+			 w->overthespotWin.midline_win) ;
+		XQueryPopdown
+			(gw, &w->overthespotWin.botline_probe, 
+			 w->overthespotWin.botline_win) ;
+		w->overthespotWin.canvas_lines = 0 ;
+		return ;
+	}
 	line_top    = text ;
-	linetop_pos = pos ;
-	x += w->overthespotWin.cursor_width ;
-	cursor_flag = True ;
-      }
-    } else {
-      x +=  (w->overthespotWin.cursor_width) ;
-      cursor_flag = True ;
-    }
-  }
- exit_loop:
-  /* ɽ٤Կ򵭲Ƥ*/
-  w->overthespotWin.canvas_lines = line_num + 1 ;
-  /*
-   *  (y - w->overthespotWin.spot_y) / w->overthespotWin.font_height + 1 ;
-   */
-  if (!cursor_flag){
-    /* ƥȤɽƤǲ̤ϤߤǤƤޤ⥫ */
-    /* Ϥޤо줷ƤʤȤɤ褦̵ˤʤäƤޤ */
-    /* ġ*/
-    /* ե꡼֤ɤΤ衩 ꡪ
-     *   ֤ɤääơĤ뤷ʤ
-     */
-    OTSW_ConfigureWindowsScreenIsSmall
-       (gw, x, y, line_top, linetop_pos, midline_top, midline_pos) ;
-    return ;
-  }
+	linetop_pos = 0 ;
+	line_num    = 0 ;
+	midline_top = NULL ;
+	cursor_flag = False ;
+	
+	/* Ĵ٤뤳Ȥˤʤ롣*/
+	for (pos = 0 ; !IS_END_OF_STRING (*text) ; text ++, pos ++){
+		xdiff = myCharTextWidth (w->overthespotWin.fontset, text, 1) ;
+		if ((x + xdiff) >= width){
+			if ((y + w->overthespotWin.font_height) >= height){
+				goto exit_loop ;
+			} else {
+				y += w->overthespotWin.font_height ;
+				x =  w->overthespotWin.client_area.x ;
+				line_num ++ ;
+			}
+			/* Ƭΰ֤ФƤϥɽȤΤɬס*/
+			line_top    = text ;
+			linetop_pos = pos ;
+			/* 2ܤιƬ֤ФƤ*/
+			if (midline_top == NULL){
+				midline_top = line_top ;
+				midline_pos = linetop_pos ;
+			}
+		}
+		/* ɽʤΤɤȽꤹ롣*/
+		if (pos == node->cur_pos &&
+			(( (y + w->overthespotWin.font_height) < height)))
+			cursor_flag = True ;
+		if (IS_ASCII_EQUAL (*text, '\n')){
+			if ((y + w->overthespotWin.font_height) >= height){
+				goto exit_loop ;
+			} else {
+				y += w->overthespotWin.font_height ;
+				x =  w->overthespotWin.client_area.x ;
+				line_num ++ ;
+			}
+			/* Ƭΰ֤ФƤϥɽȤΤɬס
+			 */
+			line_top    = text + 1 ;
+			linetop_pos = pos + 1 ;
+			/* 2ܤιƬ֤ФƤ*/
+			if (midline_top == NULL){
+				midline_top = line_top ;
+				midline_pos = linetop_pos ;
+			}
+		} else {
+			x += xdiff ;
+		}
+	}
+	/* ޤǤǥ뤬ɽƤʤäν*/
+	if (!cursor_flag){
+		/* Ԥɬפꡩ */
+		if ((x + w->overthespotWin.cursor_width) >= width){
+			if ((y + w->overthespotWin.font_height) < height){
+				y += w->overthespotWin.font_height ;
+				line_num ++ ;
+				x = w->overthespotWin.client_area.x ;
+				line_top    = text ;
+				linetop_pos = pos ;
+				x += w->overthespotWin.cursor_width ;
+				cursor_flag = True ;
+			}
+		} else {
+			x +=  (w->overthespotWin.cursor_width) ;
+			cursor_flag = True ;
+		}
+	}
+  exit_loop:
+	/* ɽ٤Կ򵭲Ƥ*/
+	w->overthespotWin.canvas_lines = line_num + 1 ;
+	/*
+	 *  (y - w->overthespotWin.spot_y) / w->overthespotWin.font_height + 1 ;
+	 */
+	if (!cursor_flag){
+		OTSW_ConfigureWindowsScreenIsSmall
+			(gw, x, y, line_top, linetop_pos, midline_top, midline_pos) ;
+		return ;
+	}
 
-  /* 饦ɥκƷ׻֤ʤɤԤ*/
-  if (w->overthespotWin.canvas_lines == 1){
-    /* ޤȤϻפɡʸʤޤʤäȤ󤸤ʤ *
-     * ͤ*/
-    if (x <= w->overthespotWin.spot_x){
-      /* ä顢ɥ˴롣*/
-      XQueryPopdown
-	 (gw, &w->overthespotWin.topline_probe,
-	  w->overthespotWin.topline_win) ;
-      XQueryPopdown
-	 (gw, &w->overthespotWin.midline_probe,
-	  w->overthespotWin.midline_win) ;
-      XQueryPopdown
-	 (gw, &w->overthespotWin.botline_probe,
-	  w->overthespotWin.botline_win) ;
-      w->overthespotWin.topline_width =
-	w->overthespotWin.botline_width = 0 ;
-      return ;
-    }
-    w->overthespotWin.topline_width = x - w->overthespotWin.spot_x ;
-  } else {
-    int width = w->overthespotWin.client_area.width - 
-      w->overthespotWin.spot_x + w->overthespotWin.client_area.x ;
-    /* եܿˤʤ餺;äƤޤʬΤƤƤ*/
-    w->overthespotWin.topline_width = width ;
-  }
-  w->overthespotWin.topline_text = node->textbuffer ;
-  w->overthespotWin.topline_pos  = 0 ;
-  w->overthespotWin.topline_x    = w->overthespotWin.spot_x ;
-
-  XMoveResizeWindow
-     (XtDisplay (gw), w->overthespotWin.topline_win,
-      w->overthespotWin.topline_x, 
-      w->overthespotWin.spot_y - w->overthespotWin.font_ascent,
-      w->overthespotWin.topline_width,
-      w->overthespotWin.font_height) ;
-
-  if (!w->overthespotWin.topline_probe){
-    XMapWindow (XtDisplay (gw), w->overthespotWin.topline_win) ;
-    w->overthespotWin.topline_probe = True ;
-  }
-
-  /* ʤν¸ߤν*/
-  if (w->overthespotWin.canvas_lines > 2){
-    w->overthespotWin.midline_text = midline_top ;
-    w->overthespotWin.midline_pos  = midline_pos ;
-
-    XMoveResizeWindow
-       (XtDisplay (gw), w->overthespotWin.midline_win,
-        w->overthespotWin.client_area.x,
-        w->overthespotWin.spot_y + w->overthespotWin.font_height - 
-        w->overthespotWin.font_ascent,
-        w->overthespotWin.client_area.width,
-        y - w->overthespotWin.spot_y - w->overthespotWin.font_height) ;
-    if (!w->overthespotWin.midline_probe){
-      XMapWindow (XtDisplay (gw), w->overthespotWin.midline_win) ;
-      w->overthespotWin.midline_probe = True ;
-    }
-  } else {
-    /* õ롣*/
-    XQueryPopdown
-       (gw, &w->overthespotWin.midline_probe, 
-	w->overthespotWin.midline_win) ;
-    w->overthespotWin.midline_text = NULL ;
-    w->overthespotWin.midline_pos  = 0 ;
-  }
-
-  /* ʤν¸ߤġ*/
-  if (w->overthespotWin.canvas_lines > 1){
-    w->overthespotWin.botline_width =
-      x - w->overthespotWin.client_area.x ;       
-    w->overthespotWin.botline_text  = line_top ;
-    w->overthespotWin.botline_pos   = linetop_pos ;
-
-    /* ɸν*/
-    XMoveResizeWindow
-       (XtDisplay (gw), w->overthespotWin.botline_win,
-        w->overthespotWin.client_area.x,
-        y - w->overthespotWin.font_ascent,
-        w->overthespotWin.botline_width,
-        w->overthespotWin.font_height) ;
-    if (!w->overthespotWin.botline_probe){
-      XMapWindow (XtDisplay (gw), w->overthespotWin.botline_win) ;
-      w->overthespotWin.botline_probe = True ;
-    }
-  } else {
-    /* ǲʤĤ롣*/
-    XQueryPopdown
-       (gw, &w->overthespotWin.botline_probe, 
-	w->overthespotWin.botline_win) ;
-    w->overthespotWin.botline_text = NULL ;
-    w->overthespotWin.botline_pos  = 0 ;
-  }
-  return ;
+	/* 饦ɥκƷ׻֤ʤɤԤ*/
+	if (w->overthespotWin.canvas_lines == 1){
+		if (x <= w->overthespotWin.spot_x){
+			XQueryPopdown
+				(gw, &w->overthespotWin.topline_probe,
+				 w->overthespotWin.topline_win) ;
+			XQueryPopdown
+				(gw, &w->overthespotWin.midline_probe,
+				 w->overthespotWin.midline_win) ;
+			XQueryPopdown
+				(gw, &w->overthespotWin.botline_probe,
+				 w->overthespotWin.botline_win) ;
+			w->overthespotWin.topline_width =
+				w->overthespotWin.botline_width = 0 ;
+			return ;
+		}
+		w->overthespotWin.topline_width = x - w->overthespotWin.spot_x ;
+	} else {
+		int width = w->overthespotWin.client_area.width - 
+			w->overthespotWin.spot_x + w->overthespotWin.client_area.x ;
+		/* եܿˤʤ餺;äƤޤʬΤƤƤ*/
+		w->overthespotWin.topline_width = width ;
+	}
+	w->overthespotWin.topline_text = node->textbuffer ;
+	w->overthespotWin.topline_pos  = 0 ;
+	w->overthespotWin.topline_x    = w->overthespotWin.spot_x ;
+	
+	XMoveResizeWindow
+		(XtDisplay (gw), w->overthespotWin.topline_win,
+		 focus_offset_x + w->overthespotWin.topline_x, 
+		 focus_offset_y + w->overthespotWin.spot_y - w->overthespotWin.font_ascent,
+		 w->overthespotWin.topline_width,
+		 w->overthespotWin.font_height) ;
+	
+	if (!w->overthespotWin.topline_probe){
+		XMapWindow (XtDisplay (gw), w->overthespotWin.topline_win) ;
+		w->overthespotWin.topline_probe = True ;
+	}
+	
+	/* ʤν¸ߤν*/
+	if (w->overthespotWin.canvas_lines > 2){
+		w->overthespotWin.midline_text = midline_top ;
+		w->overthespotWin.midline_pos  = midline_pos ;
+		
+		XMoveResizeWindow
+			(XtDisplay (gw), w->overthespotWin.midline_win,
+			 focus_offset_x + w->overthespotWin.client_area.x,
+			 focus_offset_y + w->overthespotWin.spot_y + w->overthespotWin.font_height - 
+			 w->overthespotWin.font_ascent,
+			 w->overthespotWin.client_area.width,
+			 y - w->overthespotWin.spot_y - w->overthespotWin.font_height) ;
+		if (!w->overthespotWin.midline_probe){
+			XMapWindow (XtDisplay (gw), w->overthespotWin.midline_win) ;
+			w->overthespotWin.midline_probe = True ;
+		}
+	} else {
+		/* õ롣*/
+		XQueryPopdown
+			(gw, &w->overthespotWin.midline_probe, 
+			 w->overthespotWin.midline_win) ;
+		w->overthespotWin.midline_text = NULL ;
+		w->overthespotWin.midline_pos  = 0 ;
+	}
+	
+	/* ʤν¸ߤġ*/
+	if (w->overthespotWin.canvas_lines > 1){
+		w->overthespotWin.botline_width =
+			x - w->overthespotWin.client_area.x ;       
+		w->overthespotWin.botline_text  = line_top ;
+		w->overthespotWin.botline_pos   = linetop_pos ;
+		
+		/* ɸν*/
+		XMoveResizeWindow
+			(XtDisplay (gw), w->overthespotWin.botline_win,
+			 focus_offset_x + w->overthespotWin.client_area.x,
+			 focus_offset_y + y - w->overthespotWin.font_ascent,
+			 w->overthespotWin.botline_width,
+			 w->overthespotWin.font_height) ;
+		if (!w->overthespotWin.botline_probe){
+			XMapWindow (XtDisplay (gw), w->overthespotWin.botline_win) ;
+			w->overthespotWin.botline_probe = True ;
+		}
+	} else {
+		/* ǲʤĤ롣*/
+		XQueryPopdown
+			(gw, &w->overthespotWin.botline_probe, 
+			 w->overthespotWin.botline_win) ;
+		w->overthespotWin.botline_text = NULL ;
+		w->overthespotWin.botline_pos  = 0 ;
+	}
+	return ;
 }
 
 /*
@@ -1823,128 +1813,132 @@ static void OTSW_CalcSizeOfBufferWindows (Widget gw)
  */
 static void OTSW_resetupModeWindow (Widget gw)
 {
-  OverthespotWinWidget w =  (OverthespotWinWidget)gw ;
-  int x, y, min_y, max_y, min_x, max_x ;
-  int modeshell_width, modeshell_height ;
-  XSetWindowAttributes xswa ;
-
-  modeshell_width  = getWidthOfModeLine
-     (w->overthespotWin.fontset,
-      w->overthespotWin.buffer.topbuffer,
-      w->overthespotWin.buffer.jisyo_dirty,
-      w->overthespotWin.buffer.overthespot_like_input) ;
-  modeshell_height = w->overthespotWin.font_height ;
-
-  /* 礭ΤǤ뤫ɤȽǤ롣*/
-  if (w->overthespotWin.modeshell_width != modeshell_width ||
-      w->overthespotWin.modeshell_height != modeshell_height){
-    w->overthespotWin.modeshell_width  = modeshell_width ;
-    w->overthespotWin.modeshell_height = modeshell_height ;
-    XResizeWindow
-       (XtDisplay (gw), w->overthespotWin.modeshell_win,
-	modeshell_width, modeshell_height) ;
-  }
-
-  if (!XtIsRealized (gw))
-    return ;
-
-  /* ꥵΥ⡼ɥʤС礭νʾΤȤϤʤ*/
-  if (w->overthespotWin.fixed_modeshell){
-    x = w->overthespotWin.status_area.x ;
-    y = w->overthespotWin.status_area.y ;
-  } else if (OTSW_ParseModeShellGeometry(gw)) {
-    x = w->overthespotWin.modeshell_x;
-    y = w->overthespotWin.modeshell_y;
-  } else {
-    min_x = w->overthespotWin.client_area.x ;
-    min_y = w->overthespotWin.client_area.y ;
-    max_x = min_x + 
-      w->overthespotWin.client_area.width - modeshell_width -
-      w->overthespotWin.modeshell_border_width ;
-    max_y = min_y +
-      w->overthespotWin.client_area.height - modeshell_height -
-      w->overthespotWin.modeshell_border_width * 2 ;
-    
-    xswa.win_gravity = NorthWestGravity ;
-    /* ⡼ɥɥư롣*/
-    if (!w->overthespotWin.botline_probe &&
-	!w->overthespotWin.midline_probe){
-      /* ʸϤȤʸϤƤʤС *
-       * Ʊ롣*/
-      x = w->overthespotWin.spot_x ;
-      y = w->overthespotWin.spot_y -
-	w->overthespotWin.font_ascent + w->overthespotWin.font_height ;
-    } else {
-      x = w->overthespotWin.client_area.x ;
-      y = w->overthespotWin.spot_y + 
-	w->overthespotWin.font_height * w->overthespotWin.canvas_lines -
-	w->overthespotWin.font_ascent ;
-    }
-    /* ɽ꤬뤫ɤ򸫤롣*/
-    if (x > max_x){
-      x = max_x ;
-    } else if (x < min_x){
-      x = min_x ;
-    }
-    /* Τޤɽ̤β˽ФƤޤ */
-    if (y > max_y && !w->overthespotWin.south_cursor){
+	OverthespotWinWidget w =  (OverthespotWinWidget)gw ;
+	register int x, y, min_y, max_y, min_x, max_x, focus_offset_x, focus_offset_y ;
+	register int modeshell_width, modeshell_height ;
+	XSetWindowAttributes xswa ;
+	
+	modeshell_width  = getWidthOfModeLine
+		(w->overthespotWin.fontset,
+		 w->overthespotWin.buffer.topbuffer,
+		 w->overthespotWin.buffer.jisyo_dirty,
+		 w->overthespotWin.buffer.overthespot_like_input) ;
+	modeshell_height = w->overthespotWin.font_height ;
+	
+	/* 礭ΤǤ뤫ɤȽǤ롣*/
+	if (w->overthespotWin.modeshell_width != modeshell_width ||
+		w->overthespotWin.modeshell_height != modeshell_height){
+		w->overthespotWin.modeshell_width  = modeshell_width ;
+		w->overthespotWin.modeshell_height = modeshell_height ;
+		XResizeWindow
+			(XtDisplay (gw), w->overthespotWin.modeshell_win,
+			 modeshell_width, modeshell_height) ;
+	}
+	
+	if (!XtIsRealized (gw))
+		return ;
+	
+	focus_offset_x	= w->overthespotWin.focus_offset_x ;
+	focus_offset_y	= w->overthespotWin.focus_offset_y ;
+	/* ꥵΥ⡼ɥʤС礭νʾΤȤϤʤ*/
+	if (w->overthespotWin.fixed_modeshell){
+		x = w->overthespotWin.status_area.x ;
+		y = w->overthespotWin.status_area.y ;
+		focus_offset_x	= 0 ;
+		focus_offset_y	= 0 ;
+	} else if (OTSW_ParseModeShellGeometry(gw)) {
+		x = w->overthespotWin.modeshell_x;
+		y = w->overthespotWin.modeshell_y;
+	} else {
+		min_x = w->overthespotWin.client_area.x ;
+		min_y = w->overthespotWin.client_area.y ;
+		max_x = min_x + 
+			w->overthespotWin.client_area.width - modeshell_width -
+			w->overthespotWin.modeshell_border_width ;
+		max_y = min_y +
+			w->overthespotWin.client_area.height - modeshell_height -
+			w->overthespotWin.modeshell_border_width * 2 ;
+		
+		xswa.win_gravity = NorthWestGravity ;
+		/* ⡼ɥɥư롣*/
+		if (!w->overthespotWin.botline_probe &&
+			!w->overthespotWin.midline_probe){
+			/* ʸϤȤʸϤƤʤС *
+			 * Ʊ롣*/
+			x = w->overthespotWin.spot_x ;
+			y = w->overthespotWin.spot_y -
+				w->overthespotWin.font_ascent + w->overthespotWin.font_height ;
+		} else {
+			x = w->overthespotWin.client_area.x ;
+			y = w->overthespotWin.spot_y + 
+				w->overthespotWin.font_height * w->overthespotWin.canvas_lines -
+				w->overthespotWin.font_ascent ;
+		}
+		/* ɽ꤬뤫ɤ򸫤롣*/
+		if (x > max_x){
+			x = max_x ;
+		} else if (x < min_x){
+			x = min_x ;
+		}
+		/* Τޤɽ̤β˽ФƤޤ */
+		if (y > max_y && !w->overthespotWin.south_cursor){
 #ifdef DEBUG
-      fprintf (stderr, "modeshell y = %d, max_y = %d\n", y, max_y) ;
-      fprintf (stderr, "spot_y = %d, font_ascent = %d, font_height = %d\n",
-	       w->overthespotWin.spot_y, w->overthespotWin.font_ascent,
-	       w->overthespotWin.font_height) ;
-      fprintf (stderr, "client y = %d, height = %d\n", 
-	       w->overthespotWin.client_area.y, 
-	       w->overthespotWin.client_area.height) ;
-      fprintf (stderr, "border width = %d\n",
-	       w->overthespotWin.modeshell_popup->core.border_width) ;
+			fprintf (stderr, "modeshell y = %d, max_y = %d\n", y, max_y) ;
+			fprintf (stderr, "spot_y = %d, font_ascent = %d, font_height = %d\n",
+					 w->overthespotWin.spot_y, w->overthespotWin.font_ascent,
+					 w->overthespotWin.font_height) ;
+			fprintf (stderr, "client y = %d, height = %d\n", 
+					 w->overthespotWin.client_area.y, 
+					 w->overthespotWin.client_area.height) ;
+			fprintf (stderr, "border width = %d\n",
+					 w->overthespotWin.modeshell_popup->core.border_width) ;
 #endif
-      y = w->overthespotWin.spot_y -
-	w->overthespotWin.font_ascent -
-	w->overthespotWin.modeshell_border_width * 2 -
-	w->overthespotWin.font_height ;
-      /* ̤ξ夫ФƤޤΡ */
-      if (y < min_y){
-	y = w->overthespotWin.spot_y ;
-	x = min_x ;
-      } else {
-	xswa.win_gravity = SouthWestGravity ;
-      }
-    }
-    /* Window  Gravity ꤹ롣*/
-    XChangeWindowAttributes
-       (XtDisplay (gw), w->overthespotWin.modeshell_win,
-	CWWinGravity, &xswa) ;
+			y = w->overthespotWin.spot_y -
+				w->overthespotWin.font_ascent -
+				w->overthespotWin.modeshell_border_width * 2 -
+				w->overthespotWin.font_height ;
+			/* ̤ξ夫ФƤޤΡ */
+			if (y < min_y){
+				y = w->overthespotWin.spot_y ;
+				x = min_x ;
+			} else {
+				xswa.win_gravity = SouthWestGravity ;
+			}
+		}
+		/* Window  Gravity ꤹ롣*/
+		XChangeWindowAttributes
+			(XtDisplay (gw), w->overthespotWin.modeshell_win,
+			 CWWinGravity, &xswa) ;
   }
 #ifdef DEBUG
-  fprintf (stderr, "modeshell (x,y) = (%d,%d) size = (%d,%d, %d)\n",
-	   x, y, modeshell_width, modeshell_height, 
-	   w->overthespotWin.modeshell_border_width) ;
-  fprintf (stderr, "spot (x,y) = (%d,%d)\n",
-	   w->overthespotWin.spot_x, w->overthespotWin.spot_y) ;
-  fprintf (stderr, "client (x,y) = (%d,%d) size = (%d, %d)\n",
-	   w->overthespotWin.client_area.x, 
-	   w->overthespotWin.client_area.y, 
-	   w->overthespotWin.client_area.width,
-	   w->overthespotWin.client_area.height) ;
-  fflush (stderr) ;
+	fprintf (stderr, "modeshell (x,y) = (%d,%d) size = (%d,%d, %d)\n",
+			 x, y, modeshell_width, modeshell_height, 
+			 w->overthespotWin.modeshell_border_width) ;
+	fprintf (stderr, "spot (x,y) = (%d,%d)\n",
+			 w->overthespotWin.spot_x, w->overthespotWin.spot_y) ;
+	fprintf (stderr, "client (x,y) = (%d,%d) size = (%d, %d)\n",
+			 w->overthespotWin.client_area.x, 
+			 w->overthespotWin.client_area.y, 
+			 w->overthespotWin.client_area.width,
+			 w->overthespotWin.client_area.height) ;
+	fflush (stderr) ;
 #endif
-  /* ⡼ɥɥ¸ߤƤʤääƤޤ*/
-  if (!w->overthespotWin.modeshell_probe){
-    w->overthespotWin.modeshell_probe = True ;
-    XMoveWindow
-       (XtDisplay (gw), w->overthespotWin.modeshell_win, x, y) ;
-    XMapWindow
-       (XtDisplay (gw), w->overthespotWin.modeshell_win) ;
+	/* ⡼ɥɥ¸ߤƤʤääƤޤ*/
+	if (!w->overthespotWin.modeshell_probe){
+		w->overthespotWin.modeshell_probe = True ;
+		XMoveWindow
+			(XtDisplay (gw), w->overthespotWin.modeshell_win, focus_offset_x + x, focus_offset_y + y) ;
+		XMapWindow
+			(XtDisplay (gw), w->overthespotWin.modeshell_win) ;
 #if 1
-    XRaiseWindow(XtDisplay(gw), w->overthespotWin.modeshell_win);
+		XRaiseWindow(XtDisplay(gw), w->overthespotWin.modeshell_win);
 #endif
-  } else {
-    /* ɽ֤ν򤹤롣*/
-    XMoveWindow
-       (XtDisplay (gw), w->overthespotWin.modeshell_win, x, y) ;
-  }
-  Modeshell_Display (gw, w->overthespotWin.modeshell_win) ;
+	} else {
+		/* ɽ֤ν򤹤롣*/
+		XMoveWindow
+			(XtDisplay (gw), w->overthespotWin.modeshell_win, focus_offset_x + x, focus_offset_y + y) ;
+	}
+	Modeshell_Display (gw, w->overthespotWin.modeshell_win) ;
   return ;
 }
 
@@ -1986,7 +1980,11 @@ static void OTSW_ConfigureWindowsScreenIsSmall
 	struct SKKInputNode *node = w->overthespotWin.buffer.topbuffer ;
 	int width, start_x, toppos ;
 	struct myChar *toptext ;
+	register int	focus_offset_x, focus_offset_y ;
 	
+	focus_offset_x		= w->overthespotWin.focus_offset_x ;
+	focus_offset_y		= w->overthespotWin.focus_offset_y ;
+
 	/* ǵ줿 pos  text ɽɤ*/
 	OTSW_CalcTopPositionOfBuffer
 		(w->overthespotWin.fontset,
@@ -2057,8 +2055,8 @@ static void OTSW_ConfigureWindowsScreenIsSmall
 	}
 	XMoveResizeWindow
 		(XtDisplay (gw), w->overthespotWin.topline_win,
-		 w->overthespotWin.topline_x,
-		 w->overthespotWin.spot_y - w->overthespotWin.font_ascent,
+		 focus_offset_x + w->overthespotWin.topline_x,
+		 focus_offset_y + w->overthespotWin.spot_y - w->overthespotWin.font_ascent,
 		 w->overthespotWin.topline_width,
 		 w->overthespotWin.font_height) ;
 	/* ǾʤΥ饤ɽpopup롣*/
@@ -2072,8 +2070,8 @@ static void OTSW_ConfigureWindowsScreenIsSmall
 		w->overthespotWin.midline_pos  = midline_pos ;
 		XMoveResizeWindow
 			(XtDisplay (gw), w->overthespotWin.midline_win,
-			 w->overthespotWin.client_area.x,
-			 w->overthespotWin.spot_y + 
+			 focus_offset_x + w->overthespotWin.client_area.x,
+			 focus_offset_y + w->overthespotWin.spot_y + 
 			 w->overthespotWin.font_height - w->overthespotWin.font_ascent,
 			 w->overthespotWin.client_area.width,
 			 endy - w->overthespotWin.spot_y -
@@ -2100,8 +2098,8 @@ static void OTSW_ConfigureWindowsScreenIsSmall
 		
 		XMoveResizeWindow
 			(XtDisplay (gw), w->overthespotWin.botline_win,
-			 w->overthespotWin.client_area.x, 
-			 endy - w->overthespotWin.font_ascent,
+			 focus_offset_x + w->overthespotWin.client_area.x, 
+			 focus_offset_y + endy - w->overthespotWin.font_ascent,
 			 w->overthespotWin.botline_width,
 			 w->overthespotWin.font_height) ;
 		if (!w->overthespotWin.botline_probe){
