@@ -256,7 +256,7 @@ static void SEPW_InitializeHistory( Widget gw )
     return ;
   }
   /* ꤷȤСġ*/
-  if( w->separateWin.historyAttribute->overthespot_like_input < 0 ){
+  if( w->separateWin.historyAttribute->overthespot_like_input == False){
     /* X Resource ¦ꤹ롣*/
     w->separateWin.buffer.overthespot_like_input = 
       w->separateWin.overthespotLikeInput ;
