@@ -2049,7 +2049,7 @@ static unsigned long Ximp_makeConvAttributes
       ( XIMP_PRE_FG_MASK | XIMP_PRE_BG_MASK ) ){
     attr->foreground = ximpClient->preedit_attributes.foreground ;
     attr->background = ximpClient->preedit_attributes.background ;
-    mask |= CAColor ;
+    mask |= CAForegroundPixel | CABackgroundPixel ;
   }
   if( ximpClient->attribute_mask & XIMP_PRE_COLORMAP_MASK ){
     attr->colormap = ximpClient->preedit_attributes.colormap ;
