@@ -175,8 +175,7 @@ static int skkinputLookupString
       break ;
     }
   } else {
-    if( chara == 0x20 && ( xkev->state & ShiftMask ) &&
-	!( xkev->state & ( ~ShiftMask ) ) ){
+    if( chara == 0x20 && (xkev->state & ShiftMask)) {
       chara = CHARA_SHIFT_SPACE ;
     }
   }
