@@ -22,7 +22,7 @@
 #define kanji_h
 
 struct myChar {
-	char			charset ;
+	signed char charset ;
 	unsigned short	chara ;
 } ;
 
@@ -110,7 +110,7 @@ enum {
       (wchara).charset <= CHARSET_JISX0201_1976 ) )? True : False )
 
 #define IS_ASCII_EQUAL( wchara, nchara )	\
-( ( ( (wchara).chara == (nchara) ) && \
+( ( ( (wchara).chara == (unsigned char)(nchara) ) && \
     ( (wchara).charset >= CHARSET_ISO8859_1 && \
       (wchara).charset <= CHARSET_JISX0201_1976 ) )? True : False )
 
