@@ -41,7 +41,7 @@
 #include "Ximp.h"
 #endif
 #if defined(SUPPORT_XIM)
-#include "Xim.h"
+#include "XIMServer.h"
 #endif
 #include "SeparateWin.h"
 #include "OverWin.h"
@@ -362,17 +362,17 @@ int main( int argc, char *argv[] )
 #if defined(SUPPORT_XIM)
   /* Xim Protocol Ѥ뤿νԤ*/
   if( support_xim_protocol ){
-    xim_protocol = XtVaCreateManagedWidget
-      ( "xim", ximWidgetClass, toplevel, XtNwidth, 1, XtNheight, 1, NULL ) ;
-    /* ɬפʥХåä롣*/
-    XtAddCallback
-      ( xim_protocol, XtNsetupInputWindowNotify,
-	( XtCallbackProc )setupInputWindow, ( XtPointer )NULL ) ;
-    XtAddCallback
-      ( xim_protocol, XtNserverCloseNotify,
-	( XtCallbackProc )closeProtocolServer,
-	( XtPointer )( &xim_protocol ) ) ;
-    number_of_protocols ++ ;
+	  xim_protocol = XtVaCreateManagedWidget
+		  ( "xim", ximServerWidgetClass, toplevel, XtNwidth, 1, XtNheight, 1, NULL ) ;
+	  /* ɬפʥХåä롣*/
+	  XtAddCallback
+		  ( xim_protocol, XtNsetupInputWindowNotify,
+			( XtCallbackProc )setupInputWindow, ( XtPointer )NULL ) ;
+	  XtAddCallback
+		  ( xim_protocol, XtNserverCloseNotify,
+			( XtCallbackProc )closeProtocolServer,
+			( XtPointer )( &xim_protocol ) ) ;
+	  number_of_protocols ++ ;
   }
 #endif
   if( number_of_protocols > 0 ){
