@@ -38,6 +38,7 @@
 */
 
 #define XtNkanjiFont		"kanjiFont"
+#define XtNtextNotify		"textNotify"
 #define XtNfixNotify		"fixNotify"
 #define XtNendNotify		"endNotify"
 #define XtNkeybackNotify	"keybackNotify"
@@ -114,4 +115,26 @@
 #define XtNmodeshell_geometry	"modeshell_geometry"
 #define XtCModeShell_Geometry	"ModeShell_Geometry"
 
+#if !defined (XtNpreeditStartCallback)
+#define	XtNpreeditStartCallback	"preeditStartCallback"
+#endif
+#if !defined (XtNpreeditDrawCallback)
+#define	XtNpreeditDrawCallback	"preeditDrawCallback"
+#endif
+#if !defined (XtNpreeditCaretCallback)
+#define	XtNpreeditCaretCallback	"preeditCaretCallback"
+#endif
+#if !defined (XtNpreeditDoneCallback)
+#define	XtNpreeditDoneCallback	"preeditDoneCallback"
+#endif
+#if !defined (XtNstatusStartCallback)
+#define	XtNstatusStartCallback	"statusStartCallback"
+#endif
+#if !defined (XtNstatusDrawCallback)
+#define	XtNstatusDrawCallback	"statusDrawCallback"
+#endif
+#if !defined (XtNstatusDoneCallback)
+#define	XtNstatusDoneCallback	"statusDoneCallback"
+#endif
+
 #endif
