@@ -25,6 +25,7 @@
 #include <sys/types.h>
 #include <netinet/in.h>
 #include <netdb.h>
+#include <sys/socket.h>
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <X11/IntrinsicP.h>
@@ -99,8 +100,11 @@ extern int skkinput_UndefineKey
 /*
  * skkinput ưꤹѿ
  */
-extern int  skkserv_portnum ;
+static int  skkserv_portnum ;	/* obsoleted, use skkserv_service */
 extern char *skkserv_host ;
+extern char *skkserv_service;
+extern int skkserv_pf;
+static char *skkserv_protocol_family ;
 extern char *skkinput_local_jisyo_name ;
 extern char *skkinput_backup_jisyo_name ;
 extern char *skk_local_jisyo_name ;
@@ -195,6 +199,10 @@ extern struct skk_rom_kana_rule *skkinput_rom_kana_rule_list ;
 SkkInpDef skkinput_initdef[] = {
   { "skk-port-num:",		
     PARAM_INTEGER,		&skkserv_portnum },
+  { "skk-service:",
+    PARAM_STRING,		&skkserv_service },
+  { "skk-server-protocol-family:",
+    PARAM_STRING,		&skkserv_protocol_family },
   { "skk-server-host:",	
     PARAM_STRING,		&skkserv_host },
   { "skkinput-jisyo:",
@@ -285,7 +293,7 @@ static int is_empty_line( struct myChar *ptr )
 /*
  * Boolean Ĥޤ "t"  "nil" Τɤ餬ꤵƤ뤫ؿ
  */
-static int skkinput_analize_boolean
+static int skkinput_analyze_boolean
 ( struct myChar *oneline, void *argument )
 {
   oneline = skip_empty_symbols( oneline ) ;
@@ -316,7 +324,7 @@ static struct myChar *skip_number_digit( struct myChar *ptr )
   return ptr ;
 }
 
-static struct myChar *analize_integer_sub
+static struct myChar *analyze_integer_sub
 ( struct myChar *ptr, int *result, int *value )
 {
   struct myChar *start ;
@@ -342,11 +350,11 @@ static struct myChar *analize_integer_sub
 /*
  * ʤꤵƤ뤫ؿ
  */
-static int skkinput_analize_integer
+static int skkinput_analyze_integer
 ( struct myChar *oneline, void *argument )
 {
   int result, value ;
-  oneline = analize_integer_sub( oneline, &result, &value ) ;
+  oneline = analyze_integer_sub( oneline, &result, &value ) ;
   if( !result )
     return False ;
   /* ͤμǤϤʤˤϥ顼*/
@@ -361,7 +369,7 @@ static int skkinput_analize_integer
 /*
  * ʤʸꤵƤ뤫ؿ
  */
-static int skkinput_analize_string
+static int skkinput_analyze_string
 ( struct myChar *oneline, void *argument,
   int expandFilenameFlag, int convertBackslash )
 {
@@ -395,7 +403,7 @@ static int skkinput_analize_string
  * skkinput_input_vector  skkinput_zenkaku_vector 褦
  * ؿ
  */
-static int skkinput_analize_input_vector
+static int skkinput_analyze_input_vector
 ( struct myChar *oneline, void *argument )
 {
   struct myChar *ptr ;
@@ -410,7 +418,7 @@ static int skkinput_analize_input_vector
     goto err_ret ;
   oneline ++ ;
   /* ͤȴФޤ*/
-  ptr = analize_integer_sub( oneline, &result, &value ) ;
+  ptr = analyze_integer_sub( oneline, &result, &value ) ;
   /* ̤֤äƤʤä顢ܤǤ硣*/
   if( !result )
     goto err_ret ;
@@ -471,7 +479,7 @@ static void add_skkinput_rule_list
   return ;
 }
 
-static int skkinput_analize_rule_list
+static int skkinput_analyze_rule_list
 ( struct myChar *oneline, void *argument )
 {
   struct myChar *ptr, *rstr[ 4 ] ;
@@ -491,17 +499,17 @@ static int skkinput_analize_rule_list
     if( ret < 0 ){
       while( i < 4 )
 	rstr[ i ++ ] = NULL ;
-      goto err_analize ;
+      goto err_analyze ;
     }
   }
   /* ʸ󤬽ä顢")" ĤƤȦ*/
   ptr = skip_empty_symbols( ptr ) ;
   if( !IS_ASCII_EQUAL( *ptr, ')' ) )
-    goto err_analize ;
+    goto err_analyze ;
   /* ǡ")" ³϶ʸȦ(⤷ϥȤɤ) */
   ptr ++ ;
   if( !is_empty_line( ptr ) )
-    goto err_analize ;
+    goto err_analyze ;
   /* ǡȴФޤơȡ*/
   node.state   = rstr[ 0 ] ;
   node.next    = rstr[ 1 ] ;
@@ -509,10 +517,10 @@ static int skkinput_analize_rule_list
   node.koutput = rstr[ 3 ] ;
   /* ߤξ̵֤ä顢㥨顼äϤåޤ*/
   if( node.state == NULL )
-    goto err_analize ;
+    goto err_analyze ;
   add_skkinput_rule_list( argument, node ) ;
   return True ;
-err_analize:
+err_analyze:
   for( i = 0 ; i < 4 ; i ++ ){
     if( rstr[ i ] != NULL )
       free( rstr[ i ] ) ;
@@ -521,7 +529,7 @@ err_analize:
 }
 
 /* ( "@" . "j-self-insert" ) */
-static int skkinput_analize_define_key
+static int skkinput_analyze_define_key
 ( struct myChar *oneline,
   struct myChar **rkeystring,
   struct myChar **rkeyfunction,
@@ -661,7 +669,7 @@ static int skkinput_string2function_number
 /*
  * define-key-skkmap ᤹ؿ
  */
-static int skkinput_analize_define_key_skkmap
+static int skkinput_analyze_define_key_skkmap
 ( struct myChar *oneline, int map )
 {
   struct myChar *keyfunction ;
@@ -669,7 +677,7 @@ static int skkinput_analize_define_key_skkmap
   int func_no, ret = False, uselen ;
 
   /* ޤʸΥڥ᤹롣*/
-  if( !skkinput_analize_define_key
+  if( !skkinput_analyze_define_key
       ( oneline, &keystring, &keyfunction, &uselen ) )
     return False ;
   /* ɤδؿʤΤֹ򸫤Ĵ٤롣*/
@@ -686,7 +694,7 @@ err_ret:
 /*
  * undefine-key-skkmap ᤹ؿ
  */
-static int skkinput_analize_undefine_key_skkmap
+static int skkinput_analyze_undefine_key_skkmap
 ( struct myChar *oneline, int map )
 {
   struct myChar *keystring, *keybuf ;
@@ -695,7 +703,7 @@ static int skkinput_analize_undefine_key_skkmap
   keystring = keybuf = NULL ;
 
   /* ޤʸ᤹롣*/
-  if( !skkinput_analize_string( oneline, &keystring, False, False ) )
+  if( !skkinput_analyze_string( oneline, &keystring, False, False ) )
     goto err_ret ;
   /* ξ֤ keystring ˤϡȤΤޤޤʸ󤬥ԡƤ
    * 롣ᤷʤФʤʤ*/
@@ -717,7 +725,7 @@ err_ret:
 /*
  * lisp ǽ񤫤줿Ԥ᤹ؿ
  */
-static int skkinput_analize_skkinputlisp
+static int skkinput_analyze_skkinputlisp
 ( struct myChar *oneline )
 {
   if( !skkinputlisp_weak_eval( oneline ) )
@@ -728,7 +736,7 @@ static int skkinput_analize_skkinputlisp
 /*
  * Ԥ¹Ԥؿ
  */
-static int skkinput_analize_line( struct myChar *oneline )
+static int skkinput_analyze_line( struct myChar *oneline )
 {
   int i, length ;
   struct myChar *wptr ;
@@ -744,41 +752,41 @@ static int skkinput_analize_line( struct myChar *oneline )
     /* פʸб륢¹Ԥ롣*/
     switch( skkinput_initdef[ i ].action ){
     case PARAM_BOOLEAN :
-      return skkinput_analize_boolean
+      return skkinput_analyze_boolean
 	( wptr, skkinput_initdef[ i ].argument ) ;
     case PARAM_INTEGER :
-      return skkinput_analize_integer
+      return skkinput_analyze_integer
 	( wptr, skkinput_initdef[ i ].argument ) ;
     case PARAM_STRING :
-      return skkinput_analize_string
+      return skkinput_analyze_string
 	( wptr, skkinput_initdef[ i ].argument, False, True ) ;
     case PARAM_PATH :
-      return skkinput_analize_string
+      return skkinput_analyze_string
 	( wptr, skkinput_initdef[ i ].argument, True, True ) ;
     case PARAM_INPUT_VECTOR :
-      return skkinput_analize_input_vector
+      return skkinput_analyze_input_vector
 	( wptr, skkinput_initdef[ i ].argument ) ;
     case PARAM_ROM_KANA_RULE_LIST :
-      return skkinput_analize_rule_list
+      return skkinput_analyze_rule_list
 	( wptr, skkinput_initdef[ i ].argument ) ;
 #ifdef THIS_IS_NECESSARY
     case PARAM_DEFINE_KEY_SKKMAP :
-      return skkinput_analize_define_key_skkmap( wptr, 0 ) ;
+      return skkinput_analyze_define_key_skkmap( wptr, 0 ) ;
 #endif
     case PARAM_DEFINE_KEY_SKKJMAP :
-      return skkinput_analize_define_key_skkmap( wptr, 1 ) ;
+      return skkinput_analyze_define_key_skkmap( wptr, 1 ) ;
     case PARAM_DEFINE_KEY_ABBREVMAP :
-      return skkinput_analize_define_key_skkmap( wptr, 2 ) ;
+      return skkinput_analyze_define_key_skkmap( wptr, 2 ) ;
 #ifdef THIS_IS_NECESSARY
     case PARAM_UNDEFINE_KEY_SKKMAP :
-      return skkinput_analize_undefine_key_skkmap( wptr, 0 ) ;
+      return skkinput_analyze_undefine_key_skkmap( wptr, 0 ) ;
 #endif
     case PARAM_UNDEFINE_KEY_SKKJMAP :
-      return skkinput_analize_undefine_key_skkmap( wptr, 1 ) ;
+      return skkinput_analyze_undefine_key_skkmap( wptr, 1 ) ;
     case PARAM_UNDEFINE_KEY_ABBREVMAP :
-      return skkinput_analize_undefine_key_skkmap( wptr, 2 ) ;
+      return skkinput_analyze_undefine_key_skkmap( wptr, 2 ) ;
     case PARAM_SKKINPUTLISP :
-      return skkinput_analize_skkinputlisp( wptr ) ;
+      return skkinput_analyze_skkinputlisp( wptr ) ;
     default :
       return False ;
     }
@@ -890,7 +898,7 @@ int skkinput_readConfigFile( char *config_file )
     if( ( oneline = mychar_readOneLine( fp, coding_system ) ) != NULL ){
       /* ȹԤäˤ̵뤹롣*/
       if( !is_empty_line( oneline ) ){
-	if( !skkinput_analize_line( oneline ) ){
+	if( !skkinput_analyze_line( oneline ) ){
 	  fprintf( stderr, "Warning: I ignore line %ld.\n", line ) ;
 	}
       }
@@ -906,6 +914,29 @@ int skkinput_readConfigFile( char *config_file )
   /* rom-kana rule list ꤹ롣*/
   skkinput_rom_kana_rule_list = 
     makeSkkRomKanaRuleList( skkinput_rom_kana_rule_list_top ) ;
+
+  /* 
+   * if skkserv_portnum is defined use skkserv_portnum for 
+   * backward compatibility.
+   */
+  if (skkserv_portnum != 0) {
+    if (skkserv_service) free(skkserv_service);
+    skkserv_service = malloc(8); /* 8 digit is enough */
+    sprintf(skkserv_service, "%u", skkserv_portnum);
+  }
+  if (skkserv_protocol_family != NULL) {
+    if (strcasecmp(skkserv_protocol_family, "inet4") == 0
+	|| strcasecmp(skkserv_protocol_family, "ipv4") == 0) {
+      skkserv_pf = PF_INET;
+    } else if (strcasecmp(skkserv_protocol_family, "inet6") == 0
+	       || strcasecmp(skkserv_protocol_family, "ipv6") == 0) {
+#if defined(USE_INET6)
+      skkserv_pf = PF_INET6;
+#else
+      fprintf( stderr, "Warning: IPv6 not supported.\n" ) ;
+#endif
+    }
+  }
   return True ;
 }
 
@@ -998,10 +1029,10 @@ void initSkkinputDousaketteiVariables( void )
   servent = getservbyname( SKKSERV_SERVICE_NAME, SKKSERV_SERVICE_PROTO ) ;
   if( servent == NULL ){
     /* /etc/services ϤʤäΤǡconfig.h ΤȤ*/
-    skkserv_portnum          = atoi( DEFAULT_SKKPORT ) ;
+    skkserv_service          = strdup(DEFAULT_SKKPORT);
   } else {
     /* /etc/services ꤬äġ*/
-    skkserv_portnum          = htons( servent->s_port ) ;
+    skkserv_service          = strdup( servent->s_name ) ;
 #if defined(DEBUG)
     fprintf
       ( stderr, "getservbyname: \"%s\", %d\n",
