@@ -863,7 +863,8 @@ void skkinput_updateLocalJisyo( void )
 {
   FILE *fpSrc, *fpDest ;
   unsigned long lines ;
-  char *tempfilename ;
+  char tempfilename[64] ; /* "/tmp" + 16 + 1? */
+  int tmpfd;
 
 #ifdef DEBUG_LDIC
   fprintf( stderr, "Now saving ....\"%s\"\n", skkinput_local_jisyo_path ) ;
@@ -890,7 +891,12 @@ void skkinput_updateLocalJisyo( void )
    * ¸ߤʤϤɤΤ */
 
   /* ιԤݤѤƥݥե롣*/
-  tempfilename = tmpnam( NULL ) ;
+  strcpy(tempfilename, "/tmp/skkinputXXXXXX");
+  tmpfd = mkstemp(tempfilename);
+  if (tmpfd < 0) {
+      perror("skkinput: cannot create temp file");
+      return;
+  }
 
   /* ɽ꼭ΥХååפ롣Ԥʤ󤫤Τʤ*/
   unlink( skkinput_jisyo_backup_path ) ;
@@ -901,7 +907,8 @@ void skkinput_updateLocalJisyo( void )
   skkinput_copyFile
     ( skkinput_local_jisyo_path, tempfilename ) ;
   /* ɽ꼭Υԡ¸ߤʤ̣֤Ǥ롣*/
-  if( ( fpSrc = fopen( tempfilename, "rb" ) ) == NULL ){
+  if( ( fpSrc = fdopen( tmpfd, "rb" ) ) == NULL ){
+    close(tmpfd);
 #ifdef DEBUG_LDIC
     fprintf( stderr, "cannot create backup jisyo...error!\n" ) ;
 #endif
@@ -922,6 +929,7 @@ void skkinput_updateLocalJisyo( void )
     /* file coding system Ĵľ*/
     skkinput_local_jisyo_coding_system = 
       check_skkinput_jisyo_code( skkinput_local_jisyo_path ) ;
+    unlink( tempfilename ) ;
     return ;
   }
   lines = 0 ;
