@@ -470,9 +470,10 @@ int cmpCandidate
 	 * ʤȤʤȡĤĤޤ i == len ˤʤäƤʤȤ *
 	 * ϡϤޤޤ³ȤȤ顢֤ͤξ *
 	 * */
-	return (-1) ;
+	len = -1;
+      } else {
+	ptr1 = sNode1->text ;
       }
-      ptr1 = sNode1->text ;
     }
     if( pos2 >= sNode2->used ){
       /* ХåեκǸޤƤޤäˤϡΥΡɤ򸫤롣*/
@@ -482,10 +483,23 @@ int cmpCandidate
 	 * ʤȤʤȡĤĤޤ i == len ˤʤäƤʤȤ *
 	 * ϡϤޤޤ³ȤȤ顢֤ͤξ *
 	 * */
-	return 1 ;
+	len = -2;
+      } else {
+	ptr2 = sNode2->text ;
       }
-      ptr2 = sNode2->text ;
     }
+
+    if(len == -1 || IS_ASCII_EQUAL(*ptr1, ';')){
+      /* 1 ܤθ䤬äƤ硣 */
+      if(len == -2 || IS_ASCII_EQUAL(*ptr2, ';'))
+	return 0;
+      return (-1);
+    }
+    if(len == -2 || IS_ASCII_EQUAL(*ptr2, ';')){
+      /* 2 ܤθ䤬äƤ硣 */
+      return 1;
+    }
+
     /* κ롣*/
     if( IS_ASCII_CHARA( *ptr1 ) ){
       lchara1 = ( ( ( unsigned long )CHARSET_ASCII ) << 16 ) | 
@@ -508,14 +522,38 @@ int cmpCandidate
     ptr2 ++ ; pos2 ++ ;
     len  -- ;
   }
-  /* ʬ꤬Ʊʸä顢ɤ͡*/
-  if( len1 == len2 )
-    return 0 ;
   /* ʬĹäƤȤϡʬ礭Ρ*/
-  if( len1 > len2 )
-    return 1 ;
+  if( len1 > len2 ){
+    if( pos1 >= sNode1->used ){
+      if( ( sNode1 = sNode1->next ) == NULL ){
+	return 0;
+      }
+      ptr1 = sNode1->text ;
+    }
+    if(IS_ASCII_EQUAL(*ptr1, ';')){
+      /* 򸫤Ĥ顢ӤϽꡣ */
+      return 0;
+    }
+    return 1;
+  }
+
   /* ʬûä顢ʬΡ*/
-  return (-1) ;
+  if( len1 < len2 ){
+    if( pos2 >= sNode2->used ){
+      if( ( sNode2 = sNode2->next ) == NULL ){
+	return 0;
+      }
+      ptr2 = sNode2->text ;
+    }
+    if(IS_ASCII_EQUAL(*ptr2, ';')){
+      /* 򸫤Ĥ顢ӤϽꡣ */
+      return 0;
+    }
+    return (-1);
+  }
+
+  /* ʬ꤬Ʊʸä顢ɤ͡*/
+  return 0 ;
 }
 
 /*
